@@ -1,18 +1,21 @@
-import __future__
-
-from ..action import NHCAction
-from ..event import NHCEvent
-from ..const import PRESET_MODES
+from .action import NHCAction
+from .const import PRESET_MODES, MODES
 
 class NHCFan(NHCAction):
   def __init__(self, controller, action):
     super().__init__(controller, action)
 
+  @property
+  def modes(self) -> list:
+    return MODES
+
   @property
   def mode(self) -> str:
     for mode, value in PRESET_MODES.items():
         if value == self._state:
             return mode
 
-  def set_mode(self, speed: str) -> NHCEvent:
-      return self._controller.execute(self.action_id, PRESET_MODES[speed])
+    return PRESET_MODES['low']
+
+  def set_mode(self, preset_mode: str) -> None:
+      self._controller.execute(self.id, PRESET_MODES[preset_mode])
